import { Subject, merge, of } from 'rxjs';
const INTERVAL = 500;
export const createStartScheduler = (clearInterval, performance, setInterval) => (observer) => {
    const currentTime = performance.now();
    const subject = new Subject();
    let nextTick = currentTime + INTERVAL;
    const intervalId = setInterval(() => {
        if (performance.now() >= nextTick) {
            nextTick += INTERVAL;
            subject.next({ end: nextTick + INTERVAL, start: nextTick });
        }
    }, INTERVAL / 10);
    const subscription = merge(of({ end: nextTick + INTERVAL, start: currentTime }), subject).subscribe(observer);
    return () => {
        clearInterval(intervalId);
        return subscription.unsubscribe();
    };
};
//# sourceMappingURL=start-scheduler.js.map